@@ -77,6 +77,7 @@ from .parser import (
     Comment,
     EndTag,
     Failure,
+    initialDocumentParse,
     isASCII,
     isASCIIAlpha,
     isASCIIAlphanum,
@@ -89,6 +90,7 @@ from .parser import (
     isNoncharacter,
     isTagnameChar,
     isWhitespace,
+    nodesFromHtml,
     parseAttribute,
     parseCharRef,
     parseComment,
@@ -96,6 +98,7 @@ from .parser import (
     parseEndTag,
     ParseFailure,
     parseQuotedAttrValue,
+    ParserNode,
     parseScriptToEnd,
     parseStartTag,
     parseStyleToEnd,
@@ -103,7 +106,12 @@ from .parser import (
     parseUnquotedAttrValue,
     parseWhitespace,
     parseXmpToEnd,
+    RawElement,
     Result,
     StartTag,
     Stream,
+    Text,
+    WholeElement,
+    linesFromNodes,
+    strFromNodes,
 )
